@@ -48,18 +48,18 @@ universal_bb <- universal(davis,
                           bipartite = TRUE)
 
 ## ----hypergeometric model-----------------------------------------------------
-hyperg <- hyperg(davis)
-hyperg_bb <- backbone.extract(hyperg, signed = TRUE)
+hyperg <- bipartite.null(davis, rows = TRUE, cols = FALSE) # = hyperg(davis)
+hyperg_bb <- backbone.extract(hyperg, signed = TRUE) 
 
 ## ----sdsm, echo=T, results='hide'---------------------------------------------
-sdsm <- sdsm(davis)
+sdsm <- bipartite.null(davis, rows = TRUE, cols = TRUE) # = sdsm(davis)
 
 ## ----sdsm backbone------------------------------------------------------------
 sdsm_bb <- backbone.extract(sdsm, signed = FALSE, alpha = 0.1, fwer = "bonferroni") 
 sdsm_bb
 
 ## ----fdsm, echo=T, results='hide'---------------------------------------------
-fdsm <- fdsm(davis, trials = 100, dyad=c(1,5))
+fdsm <- bipartite.null(davis, rows = TRUE, cols = TRUE, trials = 100, dyad=c(1,5)) # = fdsm(davis, trials = 100, dyad = c(1,5))
 
 ## ----fdsm backbone------------------------------------------------------------
 fdsm$dyad_values
